/*_________________________________________________________________________________________________________________
/*|-----------------------------Copyright © Antoni Papiewski and Milan Kazarka 2020-----------------------------/*/
/*|----------Distribution of this software is only permitted in accordance with the BSL © 1.1 license----------/*/
/*|---included in the LICENSE.md file, in the software's github.com repository and on chatcola.com website.---/*/
/*¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯/*/
import path from 'path';
import appRoot from "app-root-path";
import os from "os";
import fs from "fs";

if(!process.env.PORT)
  process.env.PORT = "7777";

const isProd = ["staging", "production"].includes(process.env.NODE_ENV?.toLowerCase() || "");

const assetsPath = isProd ? 
  path.resolve(os.homedir(), ".chatcola") :
  path.resolve(appRoot.path, "assets");

if(!fs.existsSync(assetsPath))
  fs.mkdirSync(assetsPath);

const config = {
  
  port: parseInt(process.env.PORT, 10),

  client_url: process.env.CLIENT_URL,

  sentry_dsn: process.env.SENTRY_DSN,

  server: {
    key_file_name: path.resolve(assetsPath, "privkey.pem"),
    cert_file_name: path.resolve(assetsPath, "fullchain.pem")
  },
};

if(config.server.key_file_name) {

  try {
    fs.readFileSync(config.server.key_file_name);
    fs.readFileSync(config.server.cert_file_name);
  }
  catch( err ) {
    console.error(`Error reading SSL keys: `, err.message);

    if(err.code === "ENOENT")
      process.exit(2);
    else
      throw err;
  }

}

export default config;